==> jc-1.4.0.tar.gz: polyglot/types/SourceClassResolver.h <==
// public class polyglot.types.SourceClassResolver

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class eec1a4cebd785b9d polyglot_types_ClassResolver
// @dep_class 775d491e1eb77426 polyglot_types_LoadedClassResolver
// @dep_class a81fa73809a6780b polyglot_types_SourceClassResolver

// header file dependencies
// @dep_header polyglot_types_LoadedClassResolver

#include "polyglot/types/LoadedClassResolver.h"

#ifndef _JC_polyglot_types_SourceClassResolver_H_
#define _JC_polyglot_types_SourceClassResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_frontend_Compiler$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_frontend_FileSource$object;
struct _jc_polyglot_types_Named$object;
struct _jc_polyglot_types_reflect_ClassFileLoader$object;

// Typedefs
typedef struct _jc_polyglot_types_SourceClassResolver$sub_refs	_jc_polyglot_types_SourceClassResolver$sub_refs;
typedef struct _jc_polyglot_types_SourceClassResolver$sub_nonrefs	_jc_polyglot_types_SourceClassResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_SourceClassResolver$refs	_jc_polyglot_types_SourceClassResolver$refs;
typedef struct _jc_polyglot_types_SourceClassResolver$nonrefs	_jc_polyglot_types_SourceClassResolver$nonrefs;
typedef struct _jc_polyglot_types_SourceClassResolver$object	_jc_polyglot_types_SourceClassResolver$object;

typedef const struct _jc_polyglot_types_SourceClassResolver$vmethods	_jc_polyglot_types_SourceClassResolver$vmethods;
typedef const struct _jc_polyglot_types_SourceClassResolver$vtable	_jc_polyglot_types_SourceClassResolver$vtable;
typedef const struct _jc_polyglot_types_SourceClassResolver$vtype	_jc_polyglot_types_SourceClassResolver$vtype;

// Constructors
extern void _jc_polyglot_types_SourceClassResolver$method$_init$bcfadaa1eb77075d(_jc_env *, struct _jc_polyglot_types_SourceClassResolver$object *, struct _jc_polyglot_frontend_Compiler$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_types_reflect_ClassFileLoader$object *, jboolean);

// Virtual methods
extern struct _jc_object *_jc_polyglot_types_SourceClassResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_SourceClassResolver$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_polyglot_types_SourceClassResolver$method$getTypeFromSource$461c201b25d9ed0f(_jc_env *, struct _jc_polyglot_types_SourceClassResolver$object *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_SourceClassResolver$method_info$find$6acc62ea1c707b3c;
extern _jc_method _jc_polyglot_types_SourceClassResolver$method_info$getTypeFromSource$461c201b25d9ed0f;

// Virtual methods structure
struct _jc_polyglot_types_SourceClassResolver$vmethods {
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_SourceClassResolver$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*getTypeFromSource$461c201b25d9ed0f)(_jc_env *, struct _jc_polyglot_types_SourceClassResolver$object *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_polyglot_types_SourceClassResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_ClassResolver$vmethods	polyglot_types_ClassResolver;
	_jc_polyglot_types_LoadedClassResolver$vmethods	polyglot_types_LoadedClassResolver;
	_jc_polyglot_types_SourceClassResolver$vmethods	polyglot_types_SourceClassResolver;
};

// Vtype
struct _jc_polyglot_types_SourceClassResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_SourceClassResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_SourceClassResolver$sub_refs {
	struct _jc_polyglot_frontend_Compiler$object	*compiler;
	struct _jc_object	*ext;
};

// Reference instance fields (object)
struct _jc_polyglot_types_SourceClassResolver$refs {
    _jc_polyglot_types_SourceClassResolver$sub_refs	polyglot_types_SourceClassResolver;
    _jc_polyglot_types_LoadedClassResolver$sub_refs	polyglot_types_LoadedClassResolver;
    _jc_polyglot_types_ClassResolver$sub_refs	polyglot_types_ClassResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_SourceClassResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_SourceClassResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_ClassResolver$sub_nonrefs	polyglot_types_ClassResolver;
    _jc_polyglot_types_LoadedClassResolver$sub_nonrefs	polyglot_types_LoadedClassResolver;
    _jc_polyglot_types_SourceClassResolver$sub_nonrefs	polyglot_types_SourceClassResolver;
};

// Object instance structure
struct _jc_polyglot_types_SourceClassResolver$object {
	_jc_polyglot_types_SourceClassResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_SourceClassResolver$vtype	*vtype;
	_jc_polyglot_types_SourceClassResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_SourceClassResolver$vtype _jc_polyglot_types_SourceClassResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_SourceClassResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_SourceClassResolver$class_object;

#endif	/* _JC_polyglot_types_SourceClassResolver_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/SourceClassResolver.h <==
// public class polyglot.types.SourceClassResolver

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class eec1a4cebd785b9d polyglot_types_ClassResolver
// @dep_class 775d491e1eb77426 polyglot_types_LoadedClassResolver
// @dep_class a81fa73809a6780b polyglot_types_SourceClassResolver

// header file dependencies
// @dep_header polyglot_types_LoadedClassResolver

#include "polyglot/types/LoadedClassResolver.h"

#ifndef _JC_polyglot_types_SourceClassResolver_H_
#define _JC_polyglot_types_SourceClassResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_frontend_Compiler$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_frontend_FileSource$object;
struct _jc_polyglot_types_Named$object;
struct _jc_polyglot_types_reflect_ClassFileLoader$object;

// Typedefs
typedef struct _jc_polyglot_types_SourceClassResolver$sub_refs	_jc_polyglot_types_SourceClassResolver$sub_refs;
typedef struct _jc_polyglot_types_SourceClassResolver$sub_nonrefs	_jc_polyglot_types_SourceClassResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_SourceClassResolver$refs	_jc_polyglot_types_SourceClassResolver$refs;
typedef struct _jc_polyglot_types_SourceClassResolver$nonrefs	_jc_polyglot_types_SourceClassResolver$nonrefs;
typedef struct _jc_polyglot_types_SourceClassResolver$object	_jc_polyglot_types_SourceClassResolver$object;

typedef const struct _jc_polyglot_types_SourceClassResolver$vmethods	_jc_polyglot_types_SourceClassResolver$vmethods;
typedef const struct _jc_polyglot_types_SourceClassResolver$vtable	_jc_polyglot_types_SourceClassResolver$vtable;
typedef const struct _jc_polyglot_types_SourceClassResolver$vtype	_jc_polyglot_types_SourceClassResolver$vtype;

// Constructors
extern void _jc_polyglot_types_SourceClassResolver$method$_init$bcfadaa1eb77075d(_jc_env *, struct _jc_polyglot_types_SourceClassResolver$object *, struct _jc_polyglot_frontend_Compiler$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_polyglot_types_reflect_ClassFileLoader$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_types_SourceClassResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_SourceClassResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_types_SourceClassResolver$method$getTypeFromSource$461c201b25d9ed0f(_jc_env *, struct _jc_polyglot_types_SourceClassResolver$object *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_SourceClassResolver$method_info$find$6acc62ea1c707b3c;
extern _jc_method _jc_polyglot_types_SourceClassResolver$method_info$getTypeFromSource$461c201b25d9ed0f;

// Virtual methods structure
struct _jc_polyglot_types_SourceClassResolver$vmethods {
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_SourceClassResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getTypeFromSource$461c201b25d9ed0f)(_jc_env *, struct _jc_polyglot_types_SourceClassResolver$object *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_types_SourceClassResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_ClassResolver$vmethods	polyglot_types_ClassResolver;
	_jc_polyglot_types_LoadedClassResolver$vmethods	polyglot_types_LoadedClassResolver;
	_jc_polyglot_types_SourceClassResolver$vmethods	polyglot_types_SourceClassResolver;
};

// Vtype
struct _jc_polyglot_types_SourceClassResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_SourceClassResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_SourceClassResolver$sub_refs {
	struct _jc_polyglot_frontend_Compiler$object	*compiler;
	struct _jc_object	*ext;
};

// Reference instance fields (object)
struct _jc_polyglot_types_SourceClassResolver$refs {
    _jc_polyglot_types_SourceClassResolver$sub_refs	polyglot_types_SourceClassResolver;
    _jc_polyglot_types_LoadedClassResolver$sub_refs	polyglot_types_LoadedClassResolver;
    _jc_polyglot_types_ClassResolver$sub_refs	polyglot_types_ClassResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_SourceClassResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_SourceClassResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_ClassResolver$sub_nonrefs	polyglot_types_ClassResolver;
    _jc_polyglot_types_LoadedClassResolver$sub_nonrefs	polyglot_types_LoadedClassResolver;
    _jc_polyglot_types_SourceClassResolver$sub_nonrefs	polyglot_types_SourceClassResolver;
};

// Object instance structure
struct _jc_polyglot_types_SourceClassResolver$object {
	_jc_polyglot_types_SourceClassResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_SourceClassResolver$vtype	*vtype;
	_jc_polyglot_types_SourceClassResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_SourceClassResolver$vtype _jc_polyglot_types_SourceClassResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_SourceClassResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_SourceClassResolver$class_object;

#endif	/* _JC_polyglot_types_SourceClassResolver_H_ */
